@@ -7,7 +7,5 @@ def check_vector(function):
         if len(y.shape) == 1:
             y = y.reshape(-1,1) 
         result = function(self, y_predict, y)
-        if len(result.shape) == 1:
-            result = result.reshape(-1,1)
         return result
       return check
\ No newline at end of file
