@@ -198,7 +198,7 @@ class BINARY_CROSS_ENTROPY_WEIGHT:
   
   @check_vector
   def d(self, y_predict, y):
-    result = 1.0 / self.weight
+    result = self.weight
     result = result * self.derv_H_sigmoid(y_predict, y)    
 
     return result
